@@ -21,15 +21,11 @@ tmp_path="$(mktemp -d)"
 trap "rm -rf $tmp_path" EXIT
 
 sign_file() {
-    if [[ "${1##*.}" == "app" ]] ; then
-        codesign --force --options runtime --timestamp --sign  --entitlements "$src_path/default.entitlements" "$crt_name" "$1"
-    else
-        codesign --force --options runtime --timestamp --sign "$crt_name" "$1"
-    fi
+    codesign --force --options runtime --timestamp --sign "$crt_name" "$1"
 }
 
 if [[ "${app_path##*.}" = "dmg" ]] ; then # sign the application dmg
-    codesign --force --options runtime --timestamp --sign "$crt_name" --identifier "$app_id" "$app_path"
+    codesign --force --options runtime --timestamp --sign "$crt_name" --entitlements "$src_path/default.entitlements" --identifier "$app_id" "$app_path"
 else # sign the application bundle
     # find binaries and libraries inside .jar files
     find "$app_path" -name "*.jar" -type f | while read -r jar ; do
@@ -70,12 +66,12 @@ else # sign the application bundle
     # signe the jre bundle
     sign_file "$app_path/Contents/runtime"
 
+    # sign bundled cli
+    sign_file "$app_path/Contents/Helpers/embarc-cli"
+
     # sign main binary
     sign_file "$app_path/Contents/MacOS/embARC"
 
-    # sign bundled cli
-    sign_file "$app_path/Contents/tools/embarc-cli"
-
     # sign the whole application
-    codesign --force --options runtime --timestamp --sign "$crt_name" --identifier "$app_id" "$app_path"
+    codesign --force --options runtime --timestamp --sign "$crt_name"  --entitlements "$src_path/default.entitlements" --identifier "$app_id" "$app_path"
 fi
